@@ -5,6 +5,7 @@ import (
 	"os"
 	"path/filepath"
 	"strings"
+	"time"
 
 	"github.com/spf13/viper"
 
@@ -25,6 +26,20 @@ type Profile struct {
 	AccountID              string
 }
 
+// config key names
+const (
+	AccountIDName              = "account_id"
+	DeviceNameName             = "device_name"
+	DisplayNameName            = "display_name"
+	IsTermsAcceptanceValidName = "is_terms_acceptance_valid"
+	TestModeAPIKeyName         = "test_mode_api_key"
+	TestModePubKeyName         = "test_mode_pub_key"
+	TestModeKeyExpiresAtName   = "test_mode_key_expires_at"
+	LiveModeAPIKeyName         = "live_mode_api_key"
+	LiveModePubKeyName         = "live_mode_pub_key"
+	LiveModeKeyExpiresAtName   = "live_mode_key_expires_at"
+)
+
 // CreateProfile creates a profile when logging in
 func (p *Profile) CreateProfile() error {
 	writeErr := p.writeProfile(viper.GetViper())
@@ -67,7 +82,7 @@ func (p *Profile) GetDeviceName() (string, error) {
 	}
 
 	if err := viper.ReadInConfig(); err == nil {
-		return viper.GetString(p.GetConfigField("device_name")), nil
+		return viper.GetString(p.GetConfigField(DeviceNameName)), nil
 	}
 
 	return "", validators.ErrDeviceNameNotConfigured
@@ -80,7 +95,7 @@ func (p *Profile) GetAccountID() (string, error) {
 	}
 
 	if err := viper.ReadInConfig(); err == nil {
-		return viper.GetString(p.GetConfigField("account_id")), nil
+		return viper.GetString(p.GetConfigField(AccountIDName)), nil
 	}
 
 	return "", validators.ErrAccountIDNotConfigured
@@ -107,48 +122,103 @@ func (p *Profile) GetAPIKey(livemode bool) (string, error) {
 		return p.APIKey, nil
 	}
 
-	// If the user doesn't have an api_key field set, they might be using an
-	// old configuration so try to read from secret_key
-	if !livemode {
-		if !viper.IsSet(p.GetConfigField("api_key")) {
-			p.RegisterAlias("api_key", "secret_key")
-		} else {
-			p.RegisterAlias("test_mode_api_key", "api_key")
-		}
-	}
+	var key string
+	var err error
 
 	// Try to fetch the API key from the configuration file
-	if err := viper.ReadInConfig(); err == nil {
-		key := viper.GetString(p.GetConfigField(livemodeKeyField(livemode)))
+	if !livemode {
+		// If the user doesn't have an api_key field set, they might be using an
+		// old configuration so try to read from secret_key
+		if viper.IsSet(p.GetConfigField("secret_key")) {
+			p.RegisterAlias(TestModeAPIKeyName, "secret_key")
+		} else if viper.IsSet(p.GetConfigField("api_key")) {
+			p.RegisterAlias(TestModeAPIKeyName, "api_key")
+		}
 
-		err := validators.APIKey(key)
+		if err := viper.ReadInConfig(); err == nil {
+			key = viper.GetString(p.GetConfigField(TestModeAPIKeyName))
+		}
+	} else {
+		p.redactAllLivemodeValues()
+		key, err = p.retrieveLivemodeValue(LiveModeAPIKeyName)
 		if err != nil {
 			return "", err
 		}
+	}
 
+	if key != "" {
+		err = validators.APIKey(key)
+		if err != nil {
+			return "", err
+		}
 		return key, nil
 	}
 
 	return "", validators.ErrAPIKeyNotConfigured
 }
 
-// GetPublishableKey returns the publishable key for the user
-func (p *Profile) GetPublishableKey() string {
-	if err := viper.ReadInConfig(); err == nil {
-		if viper.IsSet(p.GetConfigField("publishable_key")) {
-			p.RegisterAlias("test_mode_publishable_key", "publishable_key")
-		}
+// GetExpiresAt returns the API key expirary date
+func (p *Profile) GetExpiresAt(livemode bool) (time.Time, error) {
+	var timeString string
+	var err error
 
-		return viper.GetString(p.GetConfigField("test_mode_publishable_key"))
+	if livemode {
+		timeString, err = p.retrieveLivemodeValue(LiveModeKeyExpiresAtName)
+		if err != nil {
+			return time.Time{}, err
+		}
+	} else {
+		timeString = viper.GetString(p.GetConfigField(TestModeKeyExpiresAtName))
 	}
 
-	return ""
+	if timeString != "" {
+		expiresAt, err := time.Parse(DateStringFormat, timeString)
+		if err != nil {
+			return time.Time{}, err
+		}
+		return expiresAt, nil
+	}
+
+	return time.Time{}, validators.ErrAPIKeyNotConfigured
+}
+
+// GetPublishableKey returns the publishable key for the user
+func (p *Profile) GetPublishableKey(livemode bool) (string, error) {
+	var fieldID string
+	var key string
+
+	if livemode {
+		fieldID = LiveModePubKeyName
+	} else {
+		fieldID = TestModePubKeyName
+
+		if viper.IsSet(p.GetConfigField("publishable_key")) {
+			p.RegisterAlias(TestModePubKeyName, "publishable_key")
+		}
+		// there is a bug with viper.GetStringMapString when the key name is too long, which makes
+		// `config --list --project-name <project_name>` unable to read the project specific config
+		if viper.IsSet(p.GetConfigField("test_mode_publishable_key")) {
+			p.RegisterAlias(TestModePubKeyName, "test_mode_publishable_key")
+		}
+	}
+
+	err := viper.ReadInConfig()
+	if err != nil {
+		return "", err
+	}
+
+	key = viper.GetString(p.GetConfigField(fieldID))
+	if key != "" {
+		return key, nil
+	}
+
+	return "", validators.ErrAPIKeyNotConfigured
 }
 
 // GetDisplayName returns the account display name of the user
 func (p *Profile) GetDisplayName() string {
 	if err := viper.ReadInConfig(); err == nil {
-		return viper.GetString(p.GetConfigField("display_name"))
+		return viper.GetString(p.GetConfigField(DisplayNameName))
 	}
 
 	return ""
@@ -187,6 +257,11 @@ func (p *Profile) DeleteConfigField(field string) error {
 		return err
 	}
 
+	// delete livemode redacted values from config and full values from keyring
+	if field == LiveModeAPIKeyName || field == LiveModePubKeyName || field == LiveModeKeyExpiresAtName {
+		p.deleteLivemodeValue(field)
+	}
+
 	return p.writeProfile(v)
 }
 
@@ -199,31 +274,40 @@ func (p *Profile) writeProfile(runtimeViper *viper.Viper) error {
 	}
 
 	if p.DeviceName != "" {
-		runtimeViper.Set(p.GetConfigField("device_name"), strings.TrimSpace(p.DeviceName))
+		runtimeViper.Set(p.GetConfigField(DeviceNameName), strings.TrimSpace(p.DeviceName))
 	}
 
 	if p.LiveModeAPIKey != "" {
-		runtimeViper.Set(p.GetConfigField("live_mode_api_key"), strings.TrimSpace(p.LiveModeAPIKey))
+		expiresAt := getKeyExpiresAt()
+
+		// store redacted key in config
+		runtimeViper.Set(p.GetConfigField(LiveModeAPIKeyName), RedactAPIKey(strings.TrimSpace(p.LiveModeAPIKey)))
+		runtimeViper.Set(p.GetConfigField(LiveModeKeyExpiresAtName), expiresAt)
+
+		// store actual key in secure keyring
+		p.saveLivemodeValue(LiveModeAPIKeyName, strings.TrimSpace(p.LiveModeAPIKey), "Live mode API key")
+		p.saveLivemodeValue(LiveModeKeyExpiresAtName, expiresAt, "Live mode API key expirary")
 	}
 
 	if p.LiveModePublishableKey != "" {
-		runtimeViper.Set(p.GetConfigField("live_mode_publishable_key"), strings.TrimSpace(p.LiveModePublishableKey))
+		runtimeViper.Set(p.GetConfigField(LiveModePubKeyName), strings.TrimSpace(p.LiveModePublishableKey))
 	}
 
 	if p.TestModeAPIKey != "" {
-		runtimeViper.Set(p.GetConfigField("test_mode_api_key"), strings.TrimSpace(p.TestModeAPIKey))
+		runtimeViper.Set(p.GetConfigField(TestModeAPIKeyName), strings.TrimSpace(p.TestModeAPIKey))
+		runtimeViper.Set(p.GetConfigField(TestModeKeyExpiresAtName), getKeyExpiresAt())
 	}
 
 	if p.TestModePublishableKey != "" {
-		runtimeViper.Set(p.GetConfigField("test_mode_publishable_key"), strings.TrimSpace(p.TestModePublishableKey))
+		runtimeViper.Set(p.GetConfigField(TestModePubKeyName), strings.TrimSpace(p.TestModePublishableKey))
 	}
 
 	if p.DisplayName != "" {
-		runtimeViper.Set(p.GetConfigField("display_name"), strings.TrimSpace(p.DisplayName))
+		runtimeViper.Set(p.GetConfigField(DisplayNameName), strings.TrimSpace(p.DisplayName))
 	}
 
 	if p.AccountID != "" {
-		runtimeViper.Set(p.GetConfigField("account_id"), strings.TrimSpace(p.AccountID))
+		runtimeViper.Set(p.GetConfigField(AccountIDName), strings.TrimSpace(p.AccountID))
 	}
 
 	runtimeViper.MergeInConfig()
@@ -264,10 +348,6 @@ func (p *Profile) safeRemove(v *viper.Viper, key string) *viper.Viper {
 	return v
 }
 
-func livemodeKeyField(livemode bool) string {
-	if livemode {
-		return "live_mode_api_key"
-	}
-
-	return "test_mode_api_key"
+func getKeyExpiresAt() string {
+	return time.Now().AddDate(0, 0, KeyValidInDays).UTC().Format(DateStringFormat)
 }
