@@ -102,6 +102,8 @@ type Config struct {
 	Log *log.Logger
 	// Force use of unencrypted ws:// protocol instead of wss://
 	NoWSS bool
+	// Override default timeout
+	Timeout int64
 
 	// OutCh is the channel to send logs and statuses to for processing in other packages
 	OutCh chan websocket.IElement
@@ -535,7 +537,7 @@ func Init(ctx context.Context, cfg *Config) (*Proxy, error) {
 					CheckRedirect: func(req *http.Request, via []*http.Request) error {
 						return http.ErrUseLastResponse
 					},
-					Timeout: defaultTimeout,
+					Timeout: time.Duration(cfg.Timeout) * time.Second,
 					Transport: &http.Transport{
 						TLSClientConfig: &tls.Config{InsecureSkipVerify: cfg.SkipVerify},
 					},
@@ -722,13 +724,19 @@ func buildForwardURL(forwardURL string, destination *url.URL) (string, error) {
 		return "", fmt.Errorf("Provided forward url cannot be parsed: %s", forwardURL)
 	}
 
-	return fmt.Sprintf(
+	newForwardURL := fmt.Sprintf(
 		"%s://%s%s%s",
 		f.Scheme,
 		f.Host,
 		strings.TrimSuffix(f.Path, "/"), // avoids having a double "//"
 		destination.Path,
-	), nil
+	)
+
+	if destination.RawQuery != "" {
+		newForwardURL = newForwardURL + "?" + destination.RawQuery
+	}
+
+	return newForwardURL, nil
 }
 
 func getAPIVersionString(str *string) string {
